Module compression

Module compression 

Functions

information_score
Score the information density of a memory value. Returns 0.0 (no information) to 1.0 (high information).
should_store
Returns true if the value has enough information density to store.
should_store_with_threshold
Returns true if the value has enough information density for the given threshold.