Functions
- information_
score - Score the information density of a memory value. Returns 0.0 (no information) to 1.0 (high information).
- should_
store - Returns true if the value has enough information density to store.
- should_
store_ with_ threshold - Returns true if the value has enough information density for the given threshold.